pub struct ParameterRange {
pub kind: ParameterKind,
pub min: f64,
pub max: f64,
pub step: Option<f64>,
pub default: f64,
}Expand description
A continuous or discrete range for a single tunable parameter.
Fields
kind: ParameterKindmin: f64max: f64step: Option<f64>Discrete step size. None means continuous (deduplication is effectively disabled).
default: f64Implementations
Sourceimpl ParameterRange
impl ParameterRange
Sourcepub fn step_count(&self) -> Option<usize>
pub fn step_count(&self) -> Option<usize>
Number of discrete steps in this range, or None if step is not set or is non-positive.