VariationValue

Enum VariationValue 

pub enum VariationValue {
    Float(OrderedFloat<f64>),
    Int(i64),
}
The value for a single parameter variation.

Floating-point values use ordered_float::OrderedFloat to support hashing and equality, which are required for deduplication via std::collections::HashSet.

Examples

use zeph_experiments::VariationValue;

let f = VariationValue::from(0.7_f64);
let i = VariationValue::from(40_i64);

assert!((f.as_f64() - 0.7).abs() < f64::EPSILON);
assert_eq!(i.as_f64(), 40.0);
assert_eq!(i.to_string(), "40");

Variants



Float(OrderedFloat<f64>)

A floating-point parameter value.



Int(i64)

An integer parameter value (used for TopK, RetrievalTopK).

Implementations

Source

impl VariationValue

pub fn as_f64(&self) -> f64

Return the value as f64.

Int variants are cast to f64 via as f64 (possible precision loss for very large integers, but parameter values are always small).

Examples
use zeph_experiments::VariationValue;

assert!((VariationValue::from(0.5_f64).as_f64() - 0.5).abs() < f64::EPSILON);
assert_eq!(VariationValue::from(10_i64).as_f64(), 10.0);