pub enum VariationValue {
Float(OrderedFloat<f64>),
Int(i64),
}Expand description
The value for a single parameter variation.
Floating-point values use ordered_float::OrderedFloat to support hashing
and equality, which are required for deduplication via std::collections::HashSet.
Examples
use zeph_experiments::VariationValue;
let f = VariationValue::from(0.7_f64);
let i = VariationValue::from(40_i64);
assert!((f.as_f64() - 0.7).abs() < f64::EPSILON);
assert_eq!(i.as_f64(), 40.0);
assert_eq!(i.to_string(), "40");Variants
Float(OrderedFloat<f64>)
A floating-point parameter value.
Int(i64)
An integer parameter value (used for TopK, RetrievalTopK).
Implementations
Sourceimpl VariationValue
impl VariationValue
Sourcepub fn as_f64(&self) -> f64
pub fn as_f64(&self) -> f64
Return the value as f64.
Int variants are cast to f64 via as f64 (possible precision loss for
very large integers, but parameter values are always small).
Examples
use zeph_experiments::VariationValue;
assert!((VariationValue::from(0.5_f64).as_f64() - 0.5).abs() < f64::EPSILON);
assert_eq!(VariationValue::from(10_i64).as_f64(), 10.0);Trait Implementations
Sourceimpl Clone for VariationValue
impl Clone for VariationValue
Sourcefn clone(&self) -> VariationValue
fn clone(&self) -> VariationValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VariationValue
impl Debug for VariationValue
Sourceimpl<'de> Deserialize<'de> for VariationValue
impl<'de> Deserialize<'de> for VariationValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for VariationValue
impl Display for VariationValue
Sourceimpl From<f64> for VariationValue
impl From<f64> for VariationValue
Sourceimpl From<i64> for VariationValue
impl From<i64> for VariationValue
Sourceimpl Hash for VariationValue
impl Hash for VariationValue
Sourceimpl PartialEq for VariationValue
impl PartialEq for VariationValue
Sourceimpl Serialize for VariationValue
impl Serialize for VariationValue
impl Eq for VariationValue
impl StructuralPartialEq for VariationValue